from sitemaker.containers import container
from sitemaker.items import item
class table(container):
    def __init__(self,x=1,y=1):
        self.init()
        self.items=[]
        self.clss=None

        for i in range(0,x):
            row=[]
            for j in range(0,y):
                row.append(item())
            self.items.append(row)
                    
    def setItem(self,x=0,y=0,item=None):
        if item:
            self.items[x][y]=item
            
    def build(self):
        self.content="<table "
        if self.clss:
            self.content+=" class=\""+self.clss + "\" "
        self.content+=">\n"
        for i in self.items:
            self.content+="<tr>\n"
            for j in i:
                self.content+="<th>\n"
                self.content+=j.build()
                self.content+="</th>\n"
            self.content+="</tr>\n"
        self.content+="</table>\n"
        return self.content                



from sitemaker.items import item

class container(item):

    def __init__(self,i=None):
        self.init()
        self.items=[]
        self.clss=cls
        

    def addItem(self,item):
        self.items.append(item.getItem())

    def addLine(self,ctx):
        i=item(ctx+"<br>")
        self.items.append(i)


class paragraph(container):

       def __init__(self,i=None,cls=None):
        self.init()
        self.items=[]
        self.clss=cls
        self.tag="p"
        if i:
            self.items.append(i)
        
class tagged(container):
    def __init__(self,tag="",i=None,cls=None):
        self.init()
        self.items=[]
        if i:
            self.items.append(i)
        self.clss=cls
        self.tag=tag

    
    def build(self):
        self.content+="<"+self.tag
        if self.clss:
            self.content+=" class=\""+self.clss + "\" "
        self.content+=">\n"
        for j in self.items:
            self.content+=j.build()
        self.content+="\n</"+self.tag+">\n"
        return self.content


class div(tagged):
     def __init__(self,i=None,cls=None):
        self.init()
        self.items=[]
        self.clss=cls
        self.tag="div"
        if i:
            self.items.append(i)


class span(item):
    def __init__(self,i=None,cls=None):
        self.init()
        self.items=[]
        self.clss=cls
        self.tag="span"
        if i:
            self.items.append(i)



from sitemaker.items import item

class content:

    def __init__(self):
        self.items=[]
        
    def addItem(self,item):
        self.items.append(item.getItem())
        
    def addText(self,txt):
       self.items.append(item(txt))
        
    def build(self):
        content=""
        for item in self.items:
            content+="\n"+item.build()
        return content

      
        
class page:
    def __init__(self):
        self.header=content()
        self.content=content()
        self.footer=content()
        self.title=None
        self.rels=[]
        
        self.ctx=""
        self.path="./index.html"

    
    def build(self):
        content="<html>\n"
        content+="<head>\n"
        if self.title != None:
            content+="<title>"+self.title+"</title>\n"
        for rel in self.rels:
            content+=rel.build()+"\n"
        content+="</head>\n"
        content+="<body>\n"
        content+="<!--header begin-->"
        content+=self.header.build()+"\n"
        content+="<!--header end-->\n"
        content+="<!--content begin-->"
        content+=self.content.build()+"\n"
        content+="<!--content end-->\n"
        content+="<!--footer begin-->"
        content+=self.footer.build()+"\n"
        content+="<!--footer end-->\n"
        content+="</body>\n"
        content+="</html>\n"
        ctx=content
        return content
    
    def save(self,path="./index.html"):
        with open(path,"w") as file:
            file.write(self.build())
            
    def addRel(self,href=None,rel="Stylesheet",typ=None,name="link"):
         ctx="<"+name+" "
         if rel:
             ctx+="rel=\""+str(rel)+"\" "
         if typ:
             ctx+="type=\""+str(typ)+"\" "
         if href:
             ctx+="href=\""+str(href)+"\" "
         ctx+="/>"
         self.rels.append(item(ctx))
        
class site:
    def __init__(self):
        self.pages=[]
        
    def addPage(self,page):
        self.pages.append(page)

    def save(self):
        for page in self.pages:
            page.save()
        



def markup(s,m="",cls=None):
    ret="<"+m
    if cls:
        ret+=" class=\""+cls + "\""
    ret+=">"+s+"</"+m+">"
    return ret
    
def bold(s,cls=None):
    return markup(s,"b",cls)
    
def italic(s,cls=None):
    return markup(s,"i",cls)
    
def H(s,size=1,cls=None):
    return markup(s,("H"+str(size)),cls)



from sitemaker.navbar import *
from sitemaker.css import *
from sitemaker.items import *
from sitemaker.containers import *
from sitemaker.markup import *
from sitemaker.table import *
from sitemaker.template import *



CSS_CLASS=0
CSS_ID=1
CSS_TAG=2


class css_attr:
    def __init__(self,name,value):
        self.name=name
        self.value=value
        

class cssfile:
    def __init__(self):
         self.csss=[]
         self.path=""

    def addCss(self,item):
        self.csss.append(item)
        
    def build(self):
        ctx=""
        for c in self.csss:
            ctx+=c.build()
        return ctx

    def save(self,path="index.css"):
        with open(path,"w") as file:
            file.write(self.build())     

class css(cssfile):
    def __init__(self,name,typ=0):
        # type 0 = .name   { == class
        # type 1 = #name { == id
        # type 2 = name    { == tag
        self.name=name
        self.attrs=[]
        self.csss=[]
        self.type=typ
            
    def add(self,name,value):
       self.attrs.append(css_attr(name,value))

    def build(self):
        if self.type == 0:
            ctx="."
        elif self.type == 1:
            ctx="#"
        elif self.type == 2:
            ctx=""
        ctx+=self.name+" {\n"
        for a in self.attrs:
            ctx+=str(a.name)+": "+str(a.value)+";\n"
        for c in self.csss:
            ctx+=c.build()
        ctx+="}\n"
        return ctx
        



class item:

    def __init__(self,ctx=""):
        return self.init(ctx)

    def init(self,ctx=""):
        self.content=ctx
        
    def getItem(self):
        return self

    def setClass(self,cls):
        self.clss=cls

        
    def build(self):
        return self.content

class line(item):

    def __init__(self,ctx=""):
        self.init(ctx+"<br>")
    def setText(self,ctx=""):
        self.content=ctx+"<br>"
    def getItem(self):
        return self
        
class script(item):

    def __init__(self,ctx=""):
        self.init("<script>\n"+ctx+"\n</script>\n")
    def setText(self,ctx=""):
        self.content="<script>\n"+ctx+"\n</script>\n"
    def getItem(self):
        return self

class image(item):

    def __init__(self,src=None,cls=None):
        self.init()
        self.href=src
        self.alt=None
        self.clss=cls
        
    def setImage(self,src):
        self.href=src
        
    def setAlt(self,src):
        self.alt=src

        
    def build(self):
        
        self.content="<img "
        if self.alt:
                self.content+="alt=\""+self.alt+"\" "
        if self.href:
                self.content+="src=\""+self.href+"\" "
        if self.clss:
                self.content+="class=\""+self.clss+"\" "
        self.content+=">"
        return self.content
        
class link(item):

    def __init__(self,link=None,txt=None,cls=None):
        self.init()
        self.href=link
        self.text=txt
        self.clss=cls
        
    def setHref(self,src):
        self.href=src
        
    def setText(self,src):
        self.text=src
        
    def build(self):
        self.content="<a "
        if self.href:
                self.content+="href=\""+self.href+"\" "
        if self.clss:
                self.content+="class=\""+self.clss+"\" "
        self.content+=">"
        if self.text:
                self.content+=self.text
        self.content+="</a>"
        return self.content




from sitemaker.items import item
HORIZORTAL=0
VERTICAL=1

class navbar(item):
    def __init__(self,typ=0,cls=None):
        self.init()
        self.items=[]
        self.type=typ
        self.clss=cls
        
    def addItem(self,i):
        self.items.append(i)
        
    def build(self):
        self.content="<nav"
        if self.clss:
            self.content+=" class=\"" +self.clss+ "\" "
        self.content+=">\n"
        self.content+="<ul>\n"
        for i in self.items:
            self.content+="<li"
            if self.type == 0:
                self.content+=" style=\"display: inline;\" "
            self.content+=">"
            self.content+=i.getItem().build()
            self.content+="</li>\n"
        self.content+="</ul>\n"
        self.content+="</nav>"
        return self.content



import setuptools
long_description = ""
setuptools.setup(
     name='sitemaker',  
     version='0.2',
     scripts=[] ,
     author="sulincix",
     author_email="aa@aa.aa",
     description="A site maker",
     long_description=long_description,
   long_description_content_type="text/markdown",
     url="https://gitlab.com/sulincix/sitemaker",
     packages=['sitemaker'],
     
 )
